@@ -4,5 +4,6 @@ This package contains all the plugin modules that ship with the system.
 
 # import all the modules
 from focus.plugin.modules import (
-    apps, sites, tasks, timer
+    apps, im, notify, sites,
+    sounds, stats, tasks, timer
 )
